A translation moves every point by a fixed distance in the same direction.
X axis translation. The float argument is the offset measured in units of the local coordinate system.
{ x 1 } box
{ x -.1 } box
{ x 2.1 } box
Y axis translation. The float argument is the offset measured in units of the local coordinate system.
{ y 1 } box
{ y -.1 } box
{ y 2.1 } box
Z axis translation. The float argument is the offset measured in units of the local coordinate system.
{ z 1 } box
{ z -.1 } box
{ z 2.1 } box